@@ -342,7 +342,10 @@ class S3SubCommand(object):
 
 class ListCommand(S3SubCommand):
     def _do_command(self, parsed_args, parsed_globals):
-        bucket, key = find_bucket_key(parsed_args.paths[0][5:])
+        path = parsed_args.paths[0]
+        if path.startswith('s3://'):
+            path = path[5:]
+        bucket, key = find_bucket_key(path)
         self.service = self._session.get_service('s3')
         self.endpoint = self._get_endpoint(self.service, parsed_globals)
         if not bucket:
@@ -851,7 +854,11 @@ PARAMS_DICT = {'dryrun': {'options': {'action': 'store_true'}},
                            'dest': 'filters'}},
                'acl': {'options': {'nargs': 1,
                                    'choices': ['private', 'public-read',
-                                               'public-read-write']}},
+                                               'public-read-write', 
+                                               'authenticated-read',
+                                               'bucket-owner-read',
+                                               'bucket-owner-full-control',
+                                               'log-delivery-write']}},
                'grants': {'options': {'nargs': '+'}},
                'sse': {'options': {'action': 'store_true'}},
                'storage-class': {'options': {'nargs': 1,
